@@ -2,7 +2,7 @@
 #include "ClientInterceptor.h"
 #include <iostream>
 
-ClientInitializer::ClientInitializer (void)
+ClientInitializer::ClientInitializer ()
 {
 }
 
@@ -14,7 +14,6 @@ ClientInitializer::pre_init (PortableInterceptor::ORBInitInfo_ptr)
 void
 ClientInitializer::post_init (PortableInterceptor::ORBInitInfo_ptr info)
 {
-
   // Create and register the request interceptors.
   PortableInterceptor::ClientRequestInterceptor_ptr ci =
     PortableInterceptor::ClientRequestInterceptor::_nil ();
