@@ -2,7 +2,7 @@
 #include "ClientInterceptor.h"
 #include <iostream>
 
-ClientInitializer::ClientInitializer (void)
+ClientInitializer::ClientInitializer ()
 {
 }
 
