@@ -34,7 +34,7 @@ MessageImpl::MessageImpl
 }
 
 ::CORBA::ValueBase *
-MessageImpl::_copy_value (void)
+MessageImpl::_copy_value ()
 {
   ::CORBA::ValueBase *ret_val= 0;
   ACE_NEW_THROW_EX (
