@@ -37,11 +37,8 @@ be_enum_val::accept (be_visitor *visitor)
 }
 
 void
-be_enum_val::destroy (void)
+be_enum_val::destroy ()
 {
   this->AST_EnumVal::destroy ();
   this->be_decl::destroy ();
 }
-
-IMPL_NARROW_FROM_DECL (be_enum_val)
-
