@@ -22,20 +22,20 @@ be_extended_port::be_extended_port (
 {
 }
 
-be_extended_port::~be_extended_port (void)
+be_extended_port::~be_extended_port ()
 {
 }
 
 be_porttype *
-be_extended_port::port_type (void) const
+be_extended_port::port_type () const
 {
   return
-    be_porttype::narrow_from_decl (
+    dynamic_cast<be_porttype*> (
       this->AST_Extended_Port::port_type ());
 }
 
 void
-be_extended_port::destroy (void)
+be_extended_port::destroy ()
 {
   this->AST_Extended_Port::destroy ();
   this->be_field::destroy ();
@@ -46,6 +46,3 @@ be_extended_port::accept (be_visitor *visitor)
 {
   return visitor->visit_extended_port (this);
 }
-
-IMPL_NARROW_FROM_DECL (be_extended_port)
-
