@@ -15,8 +15,8 @@
 #include "be_visitor.h"
 
 be_finder::be_finder (UTL_ScopedName *n)
-  : COMMON_Base (1,
-                 0), //@@ Always local, never abstract
+  : COMMON_Base (true,
+                 false), //@@ Always local, never abstract
     AST_Decl (AST_Decl::NT_finder,
               n),
     UTL_Scope (AST_Decl::NT_finder),
@@ -29,12 +29,12 @@ be_finder::be_finder (UTL_ScopedName *n)
 {
 }
 
-be_finder::~be_finder (void)
+be_finder::~be_finder ()
 {
 }
 
 void
-be_finder::destroy (void)
+be_finder::destroy ()
 {
   // Call the destroy methods of our base classes.
   this->be_factory::destroy ();
@@ -46,6 +46,3 @@ be_finder::accept (be_visitor *visitor)
 {
   return visitor->visit_finder (this);
 }
-
-IMPL_NARROW_FROM_DECL (be_finder)
-IMPL_NARROW_FROM_SCOPE (be_finder)
