@@ -32,20 +32,18 @@ be_provides::be_provides (UTL_ScopedName *n,
 {
 }
 
-be_provides::~be_provides (void)
+be_provides::~be_provides ()
 {
 }
 
 be_type *
-be_provides::provides_type (void) const
+be_provides::provides_type () const
 {
   return
-    be_type::narrow_from_decl (
+    dynamic_cast<be_type*> (
       this->AST_Provides::provides_type ());
 }
 
-IMPL_NARROW_FROM_DECL (be_provides)
-
 int
 be_provides::accept (be_visitor *visitor)
 {
@@ -53,7 +51,7 @@ be_provides::accept (be_visitor *visitor)
 }
 
 void
-be_provides::destroy (void)
+be_provides::destroy ()
 {
   this->AST_Provides::destroy ();
   this->be_field::destroy ();
