@@ -19,19 +19,19 @@ be_uses::be_uses (UTL_ScopedName *n,
              n),
     be_field (uses_type,
               n),
-    original_uses_ (0)
+    original_uses_ (nullptr)
 {
 }
 
-be_uses::~be_uses (void)
+be_uses::~be_uses ()
 {
 }
 
 be_type *
-be_uses::uses_type (void) const
+be_uses::uses_type () const
 {
   return
-    be_type::narrow_from_decl (
+    dynamic_cast<be_type*> (
       this->AST_Uses::uses_type ());
 }
 
@@ -42,7 +42,7 @@ be_uses::accept (be_visitor *visitor)
 }
 
 void
-be_uses::destroy (void)
+be_uses::destroy ()
 {
   this->AST_Uses::destroy ();
   this->be_field::destroy ();
@@ -55,9 +55,7 @@ be_uses::original_uses (be_uses *original_uses)
 }
 
 be_uses *
-be_uses::original_uses (void)
+be_uses::original_uses ()
 {
   return this->original_uses_;
 }
-
-IMPL_NARROW_FROM_DECL (be_uses)
