@@ -22,7 +22,7 @@ be_visitor_args_arglist::be_visitor_args_arglist (be_visitor_context *ctx)
 {
 }
 
-be_visitor_args_arglist::~be_visitor_args_arglist (void)
+be_visitor_args_arglist::~be_visitor_args_arglist ()
 {
 }
 
@@ -32,7 +32,7 @@ int be_visitor_args_arglist::visit_argument (be_argument *node)
   this->ctx_->node (node);
 
   // Retrieve the type.
-  be_type *bt = be_type::narrow_from_decl (node->field_type ());
+  be_type *bt = dynamic_cast<be_type*> (node->field_type ());
 
   if (!bt)
     {
@@ -280,7 +280,7 @@ int be_visitor_args_arglist::visit_sequence (be_sequence *node)
   // then 'type_name' below will output 'sequence'.
   if (node->imported () && node->anonymous ())
     {
-      (void) node->create_name (0);
+      (void) node->create_name (nullptr);
     }
 
   TAO_OutStream *os = this->ctx_->stream ();
@@ -417,7 +417,7 @@ int be_visitor_args_arglist::visit_typedef (be_typedef *node)
                         -1);
     }
 
-  this->ctx_->alias (0);
+  this->ctx_->alias (nullptr);
   return 0;
 }
 
