@@ -153,7 +153,7 @@ be_visitor_args::gen_pd_arg (be_predefined_type *node,
   {
     case AST_PredefinedType::PT_any:
       *os << any_deref;
-      // fallthrough
+      ACE_FALLTHROUGH;
     case AST_PredefinedType::PT_pseudo:
     case AST_PredefinedType::PT_object:
       *os << lname << var_call;
