@@ -30,8 +30,6 @@ be_visitor_array_any_op_cs::visit_array (be_array *node)
 
   TAO_INSERT_COMMENT (os);
 
-  *os << be_global->core_versioning_begin () << be_nl;
-
   // Since we don't generate CDR stream operators for types that
   // explicitly contain a local interface (at some level), we
   // must override these Any template class methods to avoid
@@ -40,6 +38,8 @@ be_visitor_array_any_op_cs::visit_array (be_array *node)
   // type is inserted into an Any and then marshaled.
   if (node->is_local ())
     {
+      *os << be_global->core_versioning_begin () << be_nl;
+
       *os << be_nl_2
           << "namespace TAO" << be_nl
           << "{" << be_idt_nl
@@ -64,16 +64,20 @@ be_visitor_array_any_op_cs::visit_array (be_array *node)
           << "return false;" << be_uidt_nl
           << "}" << be_uidt_nl
           << "}";
+
+      *os << be_global->core_versioning_end () << be_nl;
     }
 
+  *os << be_global->anyops_versioning_begin () << be_nl;
+
   // If this is non-zero, we want to call its tc_name()
   // for the TypeCode to pass to the Any operator impls.
   be_typedef *td = this->ctx_->tdef ();
 
   *os << "void operator<<= (" << be_idt << be_idt_nl
       << "::CORBA::Any &_tao_any," << be_nl
-      << "const " << node->name () << "_forany &_tao_elem" << be_uidt_nl
-      << ")" << be_uidt_nl
+      << "const " << node->name () << "_forany &_tao_elem)" << be_uidt_nl
+      << be_uidt_nl
       << "{" << be_idt_nl
       << "TAO::Any_Array_Impl_T<" << be_idt << be_idt_nl
       << node->name () << "_slice," << be_nl
@@ -92,8 +96,8 @@ be_visitor_array_any_op_cs::visit_array (be_array *node)
 
   *os << "::CORBA::Boolean operator>>= (" << be_idt << be_idt_nl
       << "const ::CORBA::Any &_tao_any," << be_nl
-      << node->name () << "_forany &_tao_elem" << be_uidt_nl
-      << ")" << be_uidt_nl
+      << node->name () << "_forany &_tao_elem)" << be_uidt_nl
+      << be_uidt_nl
       << "{" << be_idt_nl
       << "return" << be_idt_nl
       << "TAO::Any_Array_Impl_T<" << be_idt << be_idt_nl
@@ -103,11 +107,11 @@ be_visitor_array_any_op_cs::visit_array (be_array *node)
       << "_tao_any," << be_nl
       << node->name () << "_forany::_tao_any_destructor," << be_nl
       << (td != nullptr ? td->tc_name () : node->tc_name ()) << "," << be_nl
-      << "_tao_elem.out ()" << be_uidt_nl
-      << ");" << be_uidt << be_uidt << be_uidt << be_uidt_nl
+      << "_tao_elem.out ());" << be_uidt
+      << be_uidt << be_uidt << be_uidt << be_uidt_nl
       << "}";
 
-  *os << be_global->core_versioning_end () << be_nl;
+  *os << be_global->anyops_versioning_end () << be_nl;
 
   node->cli_stub_any_op_gen (true);
   return 0;
