@@ -22,7 +22,7 @@ be_visitor_component_exh::be_visitor_component_exh (
   export_macro_ = be_global->exec_export_macro ();
 }
 
-be_visitor_component_exh::~be_visitor_component_exh (void)
+be_visitor_component_exh::~be_visitor_component_exh ()
 {
 }
 
@@ -36,8 +36,7 @@ be_visitor_component_exh::visit_component (be_component *node)
 
   this->node_ = node;
 
-  /// CIDL-generated namespace used 'CIDL_' + composition name.
-  /// Now we use 'CIAO_' + component's flat name.
+  /// Use 'CIAO_' + component's flat name.
   os_ << be_nl_2
       << "/// Namespace for implementation of " << node->full_name () << " component" << be_nl
       << "namespace CIAO_" << node->flat_name ()
@@ -74,7 +73,7 @@ be_visitor_component_exh::visit_component (be_component *node)
        ! i.done ();
        i.advance ())
     {
-      char **item = 0;
+      char **item = nullptr;
       i.next (item);
 
       UTL_ScopedName *sn =
@@ -85,24 +84,24 @@ be_visitor_component_exh::visit_component (be_component *node)
 
       AST_Decl *d = s->lookup_by_name (sn, true);
 
-      if (d == 0)
+      if (d == nullptr)
         {
           idl_global->err ()->lookup_error (sn);
 
           sn->destroy ();
           delete sn;
-          sn = 0;
+          sn = nullptr;
 
           continue;
         }
 
       sn->destroy ();
       delete sn;
-      sn = 0;
+      sn = nullptr;
 
-      be_uses *u = be_uses::narrow_from_decl (d);
+      be_uses *u = dynamic_cast<be_uses*> (d);
 
-      if (u == 0)
+      if (u == nullptr)
         {
           ACE_ERROR_RETURN ((LM_ERROR,
                              ACE_TEXT ("be_visitor_component_exh")
@@ -113,7 +112,7 @@ be_visitor_component_exh::visit_component (be_component *node)
         }
 
       be_component *c =
-        be_component::narrow_from_decl (
+        dynamic_cast<be_component*> (
           ScopeAsDecl (u->defined_in ()));
 
       if (c == node)
