@@ -35,51 +35,8 @@ be_visitor_exception_any_op_ch::visit_exception (be_exception *node)
 
   TAO_INSERT_COMMENT (os);
 
-  be_module *module = nullptr;
-  if (node->is_nested ())
-    {
-      AST_Decl *d = node;
-      AST_Decl::NodeType nt = d->node_type ();
 
-      while (nt != AST_Decl::NT_root)
-        {
-          if (nt == AST_Decl::NT_module)
-            {
-              module = dynamic_cast<be_module*> (d);
-              break;
-            }
-          else
-            {
-              d = ScopeAsDecl (d->defined_in ());
-              nt = d->node_type ();
-            }
-        }
-
-      if (module != nullptr)
-        {
-          // Some compilers handle "any" operators in a namespace
-          // corresponding to their module, others do not.
-          *os << "\n\n#if defined (ACE_ANY_OPS_USE_NAMESPACE)\n";
-
-          be_util::gen_nested_namespace_begin (os, module);
-
-          *os << be_nl_2
-              << macro << " void operator<<= (::CORBA::Any &, const ::" << node->name ()
-              << " &); // copying version" << be_nl;
-          *os << macro << " void operator<<= (::CORBA::Any &, ::" << node->name ()
-              << "*); // noncopying version" << be_nl;
-          *os << macro << " ::CORBA::Boolean operator>>= (const ::CORBA::Any &, const ::"
-              << node->name () << " *&);";
-
-          be_util::gen_nested_namespace_end (os, module);
-
-          // Emit #else.
-          *os << be_nl_2
-              << "#else\n\n";
-        }
-    }
-
-  *os << be_global->core_versioning_begin () << be_nl;
+  *os << be_global->anyops_versioning_begin () << be_nl;
 
   *os << be_nl_2
       << macro << " void operator<<= (::CORBA::Any &, const " << node->name ()
@@ -89,12 +46,7 @@ be_visitor_exception_any_op_ch::visit_exception (be_exception *node)
   *os << macro << " ::CORBA::Boolean operator>>= (const ::CORBA::Any &, const "
       << node->name () << " *&);";
 
-  *os << be_global->core_versioning_end () << be_nl;
-
-  if (module != nullptr)
-    {
-      *os << "\n\n#endif";
-    }
+  *os << be_global->anyops_versioning_end () << be_nl;
 
   // All we have to do is to visit the scope and generate code.
   if (this->visit_scope (node) == -1)
@@ -204,4 +156,3 @@ be_visitor_exception_any_op_ch::visit_union (be_union *node)
 
   return 0;
 }
-
