@@ -17,7 +17,7 @@ be_visitor_interface_fwd_ch::be_visitor_interface_fwd_ch (
 {
 }
 
-be_visitor_interface_fwd_ch::~be_visitor_interface_fwd_ch (void)
+be_visitor_interface_fwd_ch::~be_visitor_interface_fwd_ch ()
 {
 }
 
@@ -31,7 +31,7 @@ be_visitor_interface_fwd_ch::visit_interface_fwd (be_interface_fwd *node)
     }
 
   AST_Interface *fd = node->full_definition ();
-  be_interface *bfd = be_interface::narrow_from_decl (fd);
+  be_interface *bfd = dynamic_cast<be_interface*> (fd);
 
   // This will be a no-op if it has already been done for this node.
   bfd->gen_var_out_seq_decls ();
