@@ -18,14 +18,13 @@
 // ************************************************************
 
 be_visitor_operation_arglist::be_visitor_operation_arglist (
-    be_visitor_context *ctx
-  )
+    be_visitor_context *ctx)
   : be_visitor_operation (ctx),
     unused_ (false)
 {
 }
 
-be_visitor_operation_arglist::~be_visitor_operation_arglist (void)
+be_visitor_operation_arglist::~be_visitor_operation_arglist ()
 {
 }
 
@@ -33,14 +32,14 @@ int
 be_visitor_operation_arglist::visit_operation (be_operation *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  bool has_args = node->argument_count () > 0;
+  bool const has_args = node->argument_count () > 0;
 
-  *os << " (" << be_idt_nl;
+  *os << " (";
 
   switch (this->ctx_->state ())
     {
     case TAO_CodeGen::TAO_OPERATION_ARGLIST_PROXY_IMPL_XS:
-      *os << "::CORBA::Object *_collocated_tao_target_";
+      *os << be_idt_nl << "::CORBA::Object *_collocated_tao_target_";
 
       if (has_args)
         {
@@ -49,6 +48,14 @@ be_visitor_operation_arglist::visit_operation (be_operation *node)
 
       break;
     default:
+      if (has_args)
+        {
+          *os << be_idt_nl;
+        }
+      else
+        {
+          *os << be_idt;
+        }
       break;
     }
 
@@ -62,11 +69,6 @@ be_visitor_operation_arglist::visit_operation (be_operation *node)
                         -1);
     }
 
-  if (!has_args)
-    {
-      *os << "void";
-    }
-
   *os << ")" << be_uidt;
 
   switch (this->ctx_->state ())
@@ -148,24 +150,24 @@ be_visitor_operation_arglist::visit_argument (be_argument *node)
   // inside the scope of the interface node. In such cases, we would like to
   // generate the appropriate relative scoped names.
   be_operation *op =
-    be_operation::narrow_from_scope (this->ctx_->scope ());
-  be_interface *intf = 0;
+    dynamic_cast<be_operation*> (this->ctx_->scope ());
+  be_interface *intf = nullptr;
 
   // We need the interface node in which this operation was defined. However,
   // if this operation node was an attribute node in disguise, we get this
   // information from the context
-  if (op == 0)
+  if (op == nullptr)
     {
       be_factory *f =
-        be_factory::narrow_from_scope (this->ctx_->scope ());
+        dynamic_cast<be_factory*> (this->ctx_->scope ());
 
-      intf = be_interface::narrow_from_scope (f->defined_in ());
+      intf = dynamic_cast<be_interface*> (f->defined_in ());
     }
   else
     {
       intf = this->ctx_->attribute ()
-        ? be_interface::narrow_from_scope (this->ctx_->attribute ()->defined_in ())
-        : be_interface::narrow_from_scope (op->defined_in ());
+        ? dynamic_cast<be_interface*> (this->ctx_->attribute ()->defined_in ())
+        : dynamic_cast<be_interface*> (op->defined_in ());
     }
 
   // Set new scope.
