@@ -19,16 +19,13 @@
 
 be_visitor_operation_argument_invoke::be_visitor_operation_argument_invoke (
     be_visitor_context
-    *ctx
-  )
+    *ctx)
   : be_visitor_operation_argument (ctx),
     last_arg_printed_ (be_visitor_operation_argument_invoke::TAO_ARG_NONE)
 {
 }
 
-be_visitor_operation_argument_invoke::~be_visitor_operation_argument_invoke (
-    void
-  )
+be_visitor_operation_argument_invoke::~be_visitor_operation_argument_invoke ()
 {
 }
 
@@ -37,7 +34,7 @@ be_visitor_operation_argument_invoke::pre_process (be_decl *bd)
 {
   TAO_OutStream *os = this->ctx_->stream ();
 
-  be_argument *arg = be_argument::narrow_from_decl (bd);
+  be_argument *arg = dynamic_cast<be_argument*> (bd);
 
   if (!arg)
     {
@@ -97,7 +94,7 @@ be_visitor_operation_argument_invoke::pre_process (be_decl *bd)
 int
 be_visitor_operation_argument_invoke::post_process (be_decl *bd)
 {
-  be_argument *arg = be_argument::narrow_from_decl (bd);
+  be_argument *arg = dynamic_cast<be_argument*> (bd);
 
   if (!arg)
     {
