@@ -17,9 +17,7 @@ be_visitor_operation_smart_proxy_cs::be_visitor_operation_smart_proxy_cs (
 {
 }
 
-be_visitor_operation_smart_proxy_cs::~be_visitor_operation_smart_proxy_cs (
-    void
-  )
+be_visitor_operation_smart_proxy_cs::~be_visitor_operation_smart_proxy_cs ()
 {
 }
 
@@ -37,13 +35,13 @@ int be_visitor_operation_smart_proxy_cs::visit_operation (be_operation *node)
           ? this->ctx_->attribute ()->defined_in ()
           : node->defined_in ();
 
-      be_interface *intf = be_interface::narrow_from_scope (s);
+      be_interface *intf = dynamic_cast<be_interface*> (s);
 
-      if (intf == 0)
+      if (intf == nullptr)
         {
-          be_porttype *pt = be_porttype::narrow_from_scope (s);
+          be_porttype *pt = dynamic_cast<be_porttype*> (s);
 
-          if (pt == 0)
+          if (pt == nullptr)
             {
               ACE_ERROR_RETURN ((LM_ERROR,
                                  ACE_TEXT ("be_visitor_operation_")
@@ -58,7 +56,7 @@ int be_visitor_operation_smart_proxy_cs::visit_operation (be_operation *node)
             }
         }
 
-      be_type *bt = be_type::narrow_from_decl (node->return_type ());
+      be_type *bt = dynamic_cast<be_type*> (node->return_type ());
 
       if (!bt)
         {
@@ -87,7 +85,7 @@ int be_visitor_operation_smart_proxy_cs::visit_operation (be_operation *node)
       // node (i.e the operation) is already in a scope lower than intf
       // (i.e. be_interface), so for deciding the exact scope use intf.
 
-      be_decl* scope = be_scope::narrow_from_scope (intf->defined_in ())->decl ();
+      be_decl* scope = dynamic_cast<be_scope*> (intf->defined_in ())->decl ();
 
       *os << " ";
       *os << scope->full_name ();
