@@ -22,7 +22,7 @@ be_visitor_root_cdr_op::be_visitor_root_cdr_op (be_visitor_context *ctx)
 {
 }
 
-be_visitor_root_cdr_op::~be_visitor_root_cdr_op (void)
+be_visitor_root_cdr_op::~be_visitor_root_cdr_op ()
 {
 }
 
