@@ -21,7 +21,7 @@ be_visitor_typedef_any_op_ch::be_visitor_typedef_any_op_ch (
 {
 }
 
-be_visitor_typedef_any_op_ch::~be_visitor_typedef_any_op_ch (void)
+be_visitor_typedef_any_op_ch::~be_visitor_typedef_any_op_ch ()
 {
 }
 
@@ -60,7 +60,7 @@ be_visitor_typedef_any_op_ch::visit_typedef (be_typedef *node)
   // the type maybe. In the latter, we just need typedefs for the type and all
   // associated _var, _out, and other types.
 
-  be_type *bt = 0; // base type
+  be_type *bt = nullptr; // base type
 
   if (this->ctx_->tdef ())
     {
@@ -92,7 +92,7 @@ be_visitor_typedef_any_op_ch::visit_typedef (be_typedef *node)
                              "failed to accept visitor\n"),
                             -1);
         }
-      this->ctx_->alias (0); // reset
+      this->ctx_->alias (nullptr); // reset
     }
   else
     {
@@ -122,17 +122,17 @@ be_visitor_typedef_any_op_ch::visit_typedef (be_typedef *node)
                             -1);
         }
 
-      this->ctx_->tdef (0); // reset
+      this->ctx_->tdef (nullptr); // reset
     }
 
-  node->cli_hdr_any_op_gen (1);
+  node->cli_hdr_any_op_gen (true);
   return 0;
 }
 
 int
 be_visitor_typedef_any_op_ch::visit_array (be_array *node)
 {
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ())
     {
@@ -163,7 +163,7 @@ be_visitor_typedef_any_op_ch::visit_array (be_array *node)
 int
 be_visitor_typedef_any_op_ch::visit_enum (be_enum *node)
 {
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ())
     {
@@ -193,7 +193,7 @@ be_visitor_typedef_any_op_ch::visit_enum (be_enum *node)
 int
 be_visitor_typedef_any_op_ch::visit_sequence (be_sequence *node)
 {
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ())
     {
@@ -223,7 +223,7 @@ be_visitor_typedef_any_op_ch::visit_sequence (be_sequence *node)
 int
 be_visitor_typedef_any_op_ch::visit_structure (be_structure *node)
 {
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ())
     {
@@ -253,7 +253,7 @@ be_visitor_typedef_any_op_ch::visit_structure (be_structure *node)
 int
 be_visitor_typedef_any_op_ch::visit_union (be_union *node)
 {
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ())
     {
