@@ -22,7 +22,7 @@ be_visitor_typedef_any_op_cs::be_visitor_typedef_any_op_cs (
 {
 }
 
-be_visitor_typedef_any_op_cs::~be_visitor_typedef_any_op_cs (void)
+be_visitor_typedef_any_op_cs::~be_visitor_typedef_any_op_cs ()
 {
 }
 
@@ -59,7 +59,7 @@ be_visitor_typedef_any_op_cs::visit_typedef (be_typedef *node)
   // the type maybe. In the latter, we just need typedefs for the type and all
   // associated _var, _out, and other types.
 
-  be_type *bt = 0; // base type
+  be_type *bt = nullptr; // base type
 
   if (this->ctx_->tdef ())
     {
@@ -92,7 +92,7 @@ be_visitor_typedef_any_op_cs::visit_typedef (be_typedef *node)
                              ),  -1);
         }
 
-      this->ctx_->alias (0); // reset
+      this->ctx_->alias (nullptr); // reset
     }
   else
     {
@@ -101,7 +101,7 @@ be_visitor_typedef_any_op_cs::visit_typedef (be_typedef *node)
       this->ctx_->tdef (node); // save the typedef node
 
       // Grab the immediate base type node.
-      bt = be_type::narrow_from_decl (node->base_type ());
+      bt = dynamic_cast<be_type*> (node->base_type ());
 
       if (!bt)
         {
@@ -122,7 +122,7 @@ be_visitor_typedef_any_op_cs::visit_typedef (be_typedef *node)
                              ),  -1);
         }
 
-      this->ctx_->tdef (0); // Reset.
+      this->ctx_->tdef (nullptr); // Reset.
     }
 
   node->cli_stub_any_op_gen (true);
@@ -132,7 +132,7 @@ be_visitor_typedef_any_op_cs::visit_typedef (be_typedef *node)
 int
 be_visitor_typedef_any_op_cs::visit_array (be_array *node)
 {
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     bt = this->ctx_->alias ();
@@ -160,7 +160,7 @@ be_visitor_typedef_any_op_cs::visit_array (be_array *node)
 int
 be_visitor_typedef_any_op_cs::visit_enum (be_enum *node)
 {
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     bt = this->ctx_->alias ();
@@ -187,7 +187,7 @@ be_visitor_typedef_any_op_cs::visit_enum (be_enum *node)
 int
 be_visitor_typedef_any_op_cs::visit_sequence (be_sequence *node)
 {
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     bt = this->ctx_->alias ();
@@ -214,7 +214,7 @@ be_visitor_typedef_any_op_cs::visit_sequence (be_sequence *node)
 int
 be_visitor_typedef_any_op_cs::visit_structure (be_structure *node)
 {
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     bt = this->ctx_->alias ();
@@ -241,7 +241,7 @@ be_visitor_typedef_any_op_cs::visit_structure (be_structure *node)
 int
 be_visitor_typedef_any_op_cs::visit_union (be_union *node)
 {
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     bt = this->ctx_->alias ();
