@@ -17,6 +17,7 @@
 #include "be_module.h"
 #include "be_predefined_type.h"
 #include "be_sequence.h"
+#include "be_map.h"
 #include "be_string.h"
 #include "be_structure.h"
 #include "be_type.h"
@@ -31,6 +32,7 @@
 #include "be_visitor_array.h"
 #include "be_visitor_enum.h"
 #include "be_visitor_sequence.h"
+#include "be_visitor_map.h"
 #include "be_visitor_structure.h"
 #include "be_visitor_typecode.h"
 #include "be_visitor_union.h"
