@@ -20,7 +20,7 @@ be_visitor_typedef_ci::be_visitor_typedef_ci (be_visitor_context *ctx)
 {
 }
 
-be_visitor_typedef_ci::~be_visitor_typedef_ci (void)
+be_visitor_typedef_ci::~be_visitor_typedef_ci ()
 {
 }
 
@@ -48,7 +48,7 @@ be_visitor_typedef_ci::visit_typedef (be_typedef *node)
   // the type maybe. In the latter, we just need typedefs for the type and all
   // associated _var, _out, and other types.
 
-  be_type *bt = 0; // base type
+  be_type *bt = nullptr; // base type
 
   if (this->ctx_->tdef ())
     {
@@ -81,7 +81,7 @@ be_visitor_typedef_ci::visit_typedef (be_typedef *node)
                             -1);
         }
 
-      this->ctx_->alias (0);
+      this->ctx_->alias (nullptr);
     }
   else
     {
@@ -90,7 +90,7 @@ be_visitor_typedef_ci::visit_typedef (be_typedef *node)
       this->ctx_->tdef (node); // save the typedef node
 
       // grab the immediate base type node
-      bt = be_type::narrow_from_decl (node->base_type ());
+      bt = dynamic_cast<be_type*> (node->base_type ());
 
       if (!bt)
         {
@@ -111,7 +111,7 @@ be_visitor_typedef_ci::visit_typedef (be_typedef *node)
                             -1);
         }
 
-      this->ctx_->tdef (0);
+      this->ctx_->tdef (nullptr);
     }
 
   return 0;
@@ -122,7 +122,7 @@ be_visitor_typedef_ci::visit_array (be_array *node)
 {
   TAO_OutStream *os = this->ctx_->stream (); // output stream
   be_typedef *tdef = this->ctx_->tdef (); // typedef node
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   // This doesn't catch 'typedef of a typedef' if the node is
   // imported, so we check for that below before generating
@@ -170,7 +170,7 @@ be_visitor_typedef_ci::visit_array (be_array *node)
       *os << be_nl
           << "ACE_INLINE" << be_nl
           << tdef->name () << "_slice *" << be_nl;
-      *os << tdef->name () << "_alloc (void)" << be_nl;
+      *os << tdef->name () << "_alloc ()" << be_nl;
       *os << "{" << be_idt_nl;
       *os << "return " << bt->name () << "_alloc ();" << be_uidt_nl;
       *os << "}" << be_nl_2;
@@ -216,7 +216,7 @@ be_visitor_typedef_ci::visit_array (be_array *node)
 int
 be_visitor_typedef_ci::visit_sequence (be_sequence *node)
 {
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     {
@@ -247,7 +247,7 @@ be_visitor_typedef_ci::visit_sequence (be_sequence *node)
 int
 be_visitor_typedef_ci::visit_structure (be_structure *node)
 {
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     {
@@ -278,7 +278,7 @@ be_visitor_typedef_ci::visit_structure (be_structure *node)
 int
 be_visitor_typedef_ci::visit_union (be_union *node)
 {
-  be_type *bt = 0;
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     {
