@@ -18,7 +18,7 @@ be_visitor_union_discriminant_cs::be_visitor_union_discriminant_cs (
 {
 }
 
-be_visitor_union_discriminant_cs::~be_visitor_union_discriminant_cs (void)
+be_visitor_union_discriminant_cs::~be_visitor_union_discriminant_cs ()
 {
 }
 
@@ -26,8 +26,8 @@ int
 be_visitor_union_discriminant_cs::visit_enum (be_enum *node)
 {
   be_union *bu =
-    be_union::narrow_from_decl (this->ctx_->node ());
-  be_type *bt = 0;
+    dynamic_cast<be_union*> (this->ctx_->node ());
+  be_type *bt = nullptr;
 
   if (this->ctx_->alias ())
     {
