@@ -22,14 +22,14 @@ be_visitor_union_branch_public_cs::be_visitor_union_branch_public_cs (
 {
 }
 
-be_visitor_union_branch_public_cs::~be_visitor_union_branch_public_cs (void)
+be_visitor_union_branch_public_cs::~be_visitor_union_branch_public_cs ()
 {
 }
 
 int
 be_visitor_union_branch_public_cs::visit_union_branch (be_union_branch *node)
 {
-  be_type *bt = be_type::narrow_from_decl (node->field_type ());
+  be_type *bt = dynamic_cast<be_type*> (node->field_type ());
 
   if (!bt)
     {
@@ -155,7 +155,7 @@ int
 be_visitor_union_branch_public_cs::visit_structure_fwd (be_structure_fwd *node)
 {
   be_structure *s =
-    be_structure::narrow_from_decl (node->full_definition ());
+    dynamic_cast<be_structure*> (node->full_definition ());
 
   return this->visit_structure (s);
 }
@@ -183,7 +183,7 @@ int
 be_visitor_union_branch_public_cs::visit_union_fwd (be_union_fwd *node)
 {
   be_union *u =
-    be_union::narrow_from_decl (node->full_definition ());
+    dynamic_cast<be_union*> (node->full_definition ());
 
   return this->visit_union (u);
 }
