@@ -24,14 +24,14 @@ be_visitor_valuetype_field_cdr_cs::be_visitor_valuetype_field_cdr_cs (
 {
 }
 
-be_visitor_valuetype_field_cdr_cs::~be_visitor_valuetype_field_cdr_cs (void)
+be_visitor_valuetype_field_cdr_cs::~be_visitor_valuetype_field_cdr_cs ()
 {
 }
 
 int
 be_visitor_valuetype_field_cdr_cs::visit_field (be_field *node)
 {
-  be_type *bt = be_type::narrow_from_decl (node->field_type ());
+  be_type *bt = dynamic_cast<be_type*> (node->field_type ());
 
   if (!bt)
     {
@@ -63,9 +63,9 @@ be_visitor_valuetype_field_cdr_cs::visit_array (be_array *node)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -92,7 +92,7 @@ be_visitor_valuetype_field_cdr_cs::visit_array (be_array *node)
       if (node->is_nested ())
         {
           be_decl *parent =
-            be_scope::narrow_from_scope (node->defined_in ())->decl ();
+            dynamic_cast<be_scope*> (node->defined_in ())->decl ();
           ACE_OS::sprintf (fname,
                            "%s::_%s",
                            parent->full_name (),
@@ -168,9 +168,9 @@ be_visitor_valuetype_field_cdr_cs::visit_enum (be_enum *node)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -230,9 +230,9 @@ be_visitor_valuetype_field_cdr_cs::visit_interface (be_interface *node)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -280,9 +280,9 @@ be_visitor_valuetype_field_cdr_cs::visit_interface_fwd (be_interface_fwd *node)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -336,9 +336,9 @@ be_visitor_valuetype_field_cdr_cs::valuetype_common (be_type *)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -388,9 +388,9 @@ be_visitor_valuetype_field_cdr_cs::visit_valuetype_fwd (be_valuetype_fwd *)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -458,9 +458,9 @@ be_visitor_valuetype_field_cdr_cs::visit_predefined_type (be_predefined_type *no
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -502,6 +502,16 @@ be_visitor_valuetype_field_cdr_cs::visit_predefined_type (be_predefined_type *no
           *os << "(strm >> ::ACE_InputCDR::to_boolean ("
               << this->pre_ << f->local_name () << this->post_ << "))";
         }
+      else if (pt == AST_PredefinedType::PT_uint8)
+        {
+          *os << "(strm >> ::ACE_InputCDR::to_uint8 ("
+              << this->pre_ << f->local_name () << this->post_ << "))";
+        }
+      else if (pt == AST_PredefinedType::PT_int8)
+        {
+          *os << "(strm >> ::ACE_InputCDR::to_int8 ("
+              << this->pre_ << f->local_name () << this->post_ << "))";
+        }
       else
         {
           *os << "(strm >> " << this->pre_ << f->local_name ()
@@ -535,6 +545,16 @@ be_visitor_valuetype_field_cdr_cs::visit_predefined_type (be_predefined_type *no
           *os << "(strm << ::ACE_OutputCDR::from_boolean ("
               << this->pre_ << f->local_name () << this->post_ << "))";
         }
+      else if (pt == AST_PredefinedType::PT_uint8)
+        {
+          *os << "(strm << ::ACE_OutputCDR::from_uint8 ("
+              << this->pre_ << f->local_name () << this->post_ << "))";
+        }
+      else if (pt == AST_PredefinedType::PT_int8)
+        {
+          *os << "(strm << ::ACE_OutputCDR::from_int8 ("
+              << this->pre_ << f->local_name () << this->post_ << "))";
+        }
       else
         {
           *os << "(strm << " << this->pre_ << f->local_name ()
@@ -563,9 +583,9 @@ be_visitor_valuetype_field_cdr_cs::visit_sequence (be_sequence *node)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -628,9 +648,9 @@ be_visitor_valuetype_field_cdr_cs::visit_string (be_string *str)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -644,7 +664,7 @@ be_visitor_valuetype_field_cdr_cs::visit_string (be_string *str)
   switch (this->ctx_->sub_state ())
     {
     case TAO_CodeGen::TAO_CDR_INPUT:
-      if (str != 0 && str->max_size ()->ev ()->u.ulval != 0)
+      if (str != nullptr && str->max_size ()->ev ()->u.ulval != 0)
         {
           if (str->width () == (long) sizeof (char))
             {
@@ -666,7 +686,7 @@ be_visitor_valuetype_field_cdr_cs::visit_string (be_string *str)
         }
       break;
     case TAO_CodeGen::TAO_CDR_OUTPUT:
-      if (str != 0 && str->max_size ()->ev ()->u.ulval != 0)
+      if (str != nullptr && str->max_size ()->ev ()->u.ulval != 0)
         {
           if (str->width () == (long) sizeof (char))
             {
@@ -710,9 +730,9 @@ be_visitor_valuetype_field_cdr_cs::visit_structure (
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -782,7 +802,7 @@ be_visitor_valuetype_field_cdr_cs::visit_typedef (be_typedef *node)
                         -1);
     }
 
-  this->ctx_->alias (0);
+  this->ctx_->alias (nullptr);
   return 0;
 }
 
@@ -793,9 +813,9 @@ be_visitor_valuetype_field_cdr_cs::visit_union (be_union *node)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -869,7 +889,7 @@ be_visitor_valuetype_field_cdr_decl::be_visitor_valuetype_field_cdr_decl (
 int
 be_visitor_valuetype_field_cdr_decl::visit_field (be_field *node)
 {
-  be_type *bt = be_type::narrow_from_decl (node->field_type ());
+  be_type *bt = dynamic_cast<be_type*> (node->field_type ());
 
   if (!bt)
     {
@@ -902,9 +922,9 @@ be_visitor_valuetype_field_cdr_decl::visit_array (be_array *node)
 
   // Retrieve the field node.
   be_field *f =
-    be_field::narrow_from_decl (this->ctx_->node ());
+    dynamic_cast<be_field*> (this->ctx_->node ());
 
-  if (f == 0)
+  if (f == nullptr)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_decl::"
@@ -915,7 +935,7 @@ be_visitor_valuetype_field_cdr_decl::visit_array (be_array *node)
 
   // Retrieve the valuetype scope in which the code is generated.
   be_decl *sc = this->ctx_->scope ()->decl ();
-  be_valuetype *vt = be_valuetype::narrow_from_decl (sc);
+  be_valuetype *vt = dynamic_cast<be_valuetype*> (sc);
 
   if (!vt)
     {
@@ -944,7 +964,7 @@ be_visitor_valuetype_field_cdr_decl::visit_array (be_array *node)
       if (node->is_nested ())
         {
           be_decl *parent =
-            be_scope::narrow_from_scope (node->defined_in ())->decl ();
+            dynamic_cast<be_scope*> (node->defined_in ())->decl ();
           ACE_OS::sprintf (fname,
                            "%s::_%s",
                            parent->full_name (),
@@ -1006,6 +1026,6 @@ be_visitor_valuetype_field_cdr_decl::visit_typedef (be_typedef *node)
                         -1);
     }
 
-  this->ctx_->alias (0);
+  this->ctx_->alias (nullptr);
   return 0;
 }
