@@ -17,19 +17,19 @@ be_visitor_valuetype_field_ci::be_visitor_valuetype_field_ci (
     be_visitor_context *ctx
   )
   : be_visitor_decl (ctx),
-    in_obv_space_ (0)
+    in_obv_space_ (false)
 {
   setenclosings ("");
 }
 
-be_visitor_valuetype_field_ci::~be_visitor_valuetype_field_ci (void)
+be_visitor_valuetype_field_ci::~be_visitor_valuetype_field_ci ()
 {
 }
 
 int
 be_visitor_valuetype_field_ci::visit_field (be_field *node)
 {
-  be_type *bt = be_type::narrow_from_decl (node->field_type ());
+  be_type *bt = dynamic_cast<be_type*> (node->field_type ());
 
   if (!bt)
     {
@@ -61,8 +61,8 @@ be_visitor_valuetype_field_ci::visit_array (be_array *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
-  be_type *bt = 0;
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -108,8 +108,8 @@ be_visitor_valuetype_field_ci::visit_structure (be_structure *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
-  be_type *bt = 0;
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -155,8 +155,8 @@ be_visitor_valuetype_field_ci::visit_union (be_union *node)
 {
   be_decl *ub = this->ctx_->node ();
   be_valuetype *bu =
-    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
-  be_type *bt = 0;
+    dynamic_cast<be_valuetype*> (this->ctx_->scope ()->decl ());
+  be_type *bt = nullptr;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
