@@ -65,7 +65,6 @@ be_visitor_valuetype::visit_valuetype_scope (be_valuetype *node)
                              "(%N:%l) be_visitor_scope::visit_scope - "
                              "codegen for scope failed\n"),
                             -1);
-
         }
     }
 
@@ -843,7 +842,7 @@ be_visitor_valuetype::gen_init_defn (be_valuetype *node)
       << "public:" << be_idt_nl
       << "virtual ~" << node->local_name () << "_init ();" << be_nl;
 
-  *os << "virtual const char* tao_repository_id (void);\n" << be_nl;
+  *os << "virtual const char* tao_repository_id ();\n" << be_nl;
   *os << "// create () goes here" << be_nl;
   *os << be_uidt_nl << "};" << be_nl;
 
@@ -931,7 +930,6 @@ be_visitor_valuetype::obv_need_ref_counter (be_valuetype* node)
 bool
 be_visitor_valuetype::obv_have_ref_counter (be_valuetype* node)
 {
-
   // Just try to find a VT with concrete factory in inheritance tree.
   if (node == nullptr)
     {
