@@ -18,7 +18,7 @@ be_visitor_valuetype_fwd_ch::be_visitor_valuetype_fwd_ch (
 {
 }
 
-be_visitor_valuetype_fwd_ch::~be_visitor_valuetype_fwd_ch (void)
+be_visitor_valuetype_fwd_ch::~be_visitor_valuetype_fwd_ch ()
 {
 }
 
@@ -32,7 +32,7 @@ be_visitor_valuetype_fwd_ch::visit_valuetype_fwd (be_valuetype_fwd *node)
     }
 
   AST_Interface *fd = node->full_definition ();
-  be_valuetype *bfd = be_valuetype::narrow_from_decl (fd);
+  be_valuetype *bfd = dynamic_cast<be_valuetype*> (fd);
 
   // This will be a no-op if it has already been done for this node.
   bfd->gen_var_out_seq_decls ();
