@@ -32,10 +32,7 @@ public:
   virtual int accept (be_visitor *visitor);
 
   //Cleanup.
-  virtual void destroy (void);
-
-  // Narrowing.
-  DEF_NARROW_FROM_DECL (be_constant);
+  virtual void destroy ();
 };
 
 #endif // if !defined
