@@ -31,10 +31,7 @@ public:
   virtual int accept (be_visitor *visitor);
 
   //Cleanup.
-  virtual void destroy (void);
-
-  // Narrowing
-  DEF_NARROW_FROM_DECL (be_enum_val);
+  virtual void destroy ();
 };
 
 #endif
