@@ -16,14 +16,10 @@ public:
                 bool abstract);
 
   // Cleanup function.
-  virtual void destroy (void);
+  virtual void destroy ();
 
   // Visiting.
   virtual int accept (be_visitor *visitor);
-
-  // Narrowing.
-  DEF_NARROW_FROM_DECL (be_exception);
-  DEF_NARROW_FROM_SCOPE (be_exception);
 };
 
 #endif // end of if !defined (...)
