@@ -30,20 +30,16 @@ class be_factory : public virtual AST_Factory,
 public:
   be_factory (UTL_ScopedName *n);
 
-  ~be_factory (void);
+  ~be_factory ();
 
   /// Cleanup method.
-  virtual void destroy (void);
+  virtual void destroy ();
 
   // Visiting.
   virtual int accept (be_visitor *visitor);
 
   // Add an argument to the scope.
   virtual AST_Argument *be_add_argument (AST_Argument *arg);
-
-  // Narrowing
-  DEF_NARROW_FROM_DECL (be_factory);
-  DEF_NARROW_FROM_SCOPE (be_factory);
 };
 
 #endif // BE_FACTORY_H
