@@ -31,14 +31,11 @@ class be_porttype : public virtual AST_PortType,
 public:
   be_porttype (UTL_ScopedName *n);
 
-  virtual ~be_porttype (void);
+  virtual ~be_porttype ();
 
-  virtual void destroy (void);
+  virtual void destroy ();
 
   virtual int accept (be_visitor *visitor);
-
-  DEF_NARROW_FROM_DECL (be_porttype);
-  DEF_NARROW_FROM_SCOPE (be_porttype);
 };
 
 #endif // BE_PORTTYPE_H
