@@ -39,15 +39,11 @@ public:
   virtual int accept (be_visitor *visitor);
 
   // Cleanup.
-  virtual void destroy (void);
-
-  // Narrowing.
-
-  DEF_NARROW_FROM_DECL (be_string);
+  virtual void destroy ();
 
 protected:
   /// Overridden method to compute typecode name.
-  virtual void compute_tc_name (void);
+  virtual void compute_tc_name ();
 };
 
 #endif
