@@ -44,15 +44,10 @@ public:
                                      bool use_underscore);
 
   /// Cleanup method.
-  virtual void destroy (void);
+  virtual void destroy ();
 
   /// Visiting.
   virtual int accept (be_visitor *visitor);
-
- // Narrowing.
-
-  DEF_NARROW_FROM_DECL (be_structure);
-  DEF_NARROW_FROM_SCOPE (be_structure);
 };
 
 #endif
