@@ -43,10 +43,7 @@ public:
   virtual int accept (be_visitor *visitor);
 
   // Cleanup.
-  virtual void destroy (void);
-
-  // Narrowing.
-  DEF_NARROW_FROM_DECL (be_union_branch);
+  virtual void destroy ();
 };
 
 #endif
