@@ -31,16 +31,13 @@ public:
   be_union_fwd (AST_Union *dummy,
                 UTL_ScopedName *n);
 
-  virtual ~be_union_fwd (void);
+  virtual ~be_union_fwd ();
 
   /// Cleanup function.
-  virtual void destroy (void);
+  virtual void destroy ();
 
   // Visiting.
   virtual int accept (be_visitor* visitor);
-
-  // Narrowing.
-  DEF_NARROW_FROM_DECL (be_union_fwd);
 };
 
 #endif // if !defined
