@@ -14,10 +14,6 @@
 #ifndef _BE_VISITOR_ARRAY_ANY_OP_CS_H_
 #define _BE_VISITOR_ARRAY_ANY_OP_CS_H_
 
-// ************************************************************
-// class be_visitor_array_cs
-// ************************************************************
-
 /**
  * @class be_visitor_array_any_op_cs
  *
@@ -28,17 +24,15 @@
  */
 class be_visitor_array_any_op_cs : public be_visitor_decl
 {
-
 public:
   /// constructor
   be_visitor_array_any_op_cs (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_array_any_op_cs (void);
+  ~be_visitor_array_any_op_cs () override = default;
 
   /// visit array
-  virtual int visit_array (be_array *node);
-
+  int visit_array (be_array *node) override;
 };
 
 #endif /* _BE_VISITOR_ARRAY_ANY_OP_CS_H_ */
