@@ -13,10 +13,6 @@
 #ifndef _BE_VISITOR_ARRAY_CH_H_
 #define _BE_VISITOR_ARRAY_CH_H_
 
-// ************************************************************
-// class be_visitor_array_ch
-// ************************************************************
-
 /**
  * @class be_visitor_array_ch
  *
@@ -31,10 +27,10 @@ public:
   be_visitor_array_ch (be_visitor_context *ctx);
 
   /// destructor
-  virtual ~be_visitor_array_ch (void);
+  ~be_visitor_array_ch () override = default;
 
   /// visit the array node
-  virtual int visit_array (be_array *node);
+  int visit_array (be_array *node) override;
 };
 
 #endif /* _BE_VISITOR_ARRAY_CH_H_ */
