@@ -9,14 +9,9 @@
  */
 //=============================================================================
 
-
 #ifndef _BE_VISITOR_ARRAY_CS_H_
 #define _BE_VISITOR_ARRAY_CS_H_
 
-// ************************************************************
-// class be_visitor_array_cs
-// ************************************************************
-
 /**
  * @class be_visitor_array_cs
  *
@@ -31,10 +26,10 @@ public:
   be_visitor_array_cs (be_visitor_context *ctx);
 
   /// destructor
-  virtual ~be_visitor_array_cs (void);
+  ~be_visitor_array_cs () override = default;
 
   /// visit the array node
-  virtual int visit_array (be_array *node);
+  int visit_array (be_array *node) override;
 };
 
 #endif /* _BE_VISITOR_ARRAY_CS_H_ */
