@@ -23,7 +23,7 @@ class be_visitor_attribute_set_from_extracted
 {
 public:
   be_visitor_attribute_set_from_extracted (be_visitor_context *ctx);
-  virtual ~be_visitor_attribute_set_from_extracted (void);
+  virtual ~be_visitor_attribute_set_from_extracted ();
 
   virtual int visit_array (be_array *);
   virtual int visit_component (be_component *);
