@@ -24,7 +24,7 @@ class be_visitor_component_exh
 public:
   be_visitor_component_exh (be_visitor_context *ctx);
 
-  ~be_visitor_component_exh (void);
+  ~be_visitor_component_exh ();
 
   virtual int visit_component (be_component *node);
 };
