@@ -23,7 +23,7 @@ class be_visitor_facet_exs
 public:
   be_visitor_facet_exs (be_visitor_context *ctx);
 
-  ~be_visitor_facet_exs (void);
+  ~be_visitor_facet_exs ();
 
   virtual int visit_operation (be_operation *node);
   virtual int visit_attribute (be_attribute *node);
