@@ -32,12 +32,12 @@ class be_visitor_connector_ami_exs
 public:
   be_visitor_connector_ami_exs (be_visitor_context *ctx);
 
-  ~be_visitor_connector_ami_exs (void);
+  ~be_visitor_connector_ami_exs ();
 
   virtual int visit_connector (be_connector *node);
 
 private:
-  void gen_entrypoint (void);
+  void gen_entrypoint ();
 };
 
 #endif /* _BE_CONNECTOR_CONNECTOR_AMI_EXS_H_ */
