@@ -29,7 +29,7 @@ class be_visitor_connector_dds_exs
 public:
   be_visitor_connector_dds_exs (be_visitor_context *ctx);
 
-  ~be_visitor_connector_dds_exs (void);
+  ~be_visitor_connector_dds_exs ();
 
   virtual int visit_connector (be_connector *node);
 };
