@@ -29,7 +29,7 @@ class be_visitor_executor_ami_exs
 public:
   be_visitor_executor_ami_exs (be_visitor_context *ctx);
 
-  ~be_visitor_executor_ami_exs (void);
+  ~be_visitor_executor_ami_exs ();
 
   virtual int visit_connector (be_connector *node);
   virtual int visit_provides (be_provides *node);
