@@ -28,7 +28,7 @@ public:
   be_visitor_constant_ch (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_constant_ch (void);
+  ~be_visitor_constant_ch ();
 
   /// visit constant.
   virtual int visit_constant (be_constant *node);
