@@ -25,7 +25,7 @@ class be_visitor_exception_ch : public be_visitor_exception
 {
 public:
   be_visitor_exception_ch (be_visitor_context *ctx);
-  ~be_visitor_exception_ch (void);
+  ~be_visitor_exception_ch ();
 
   virtual int visit_exception (be_exception *node);
 };
