@@ -25,7 +25,7 @@ class be_visitor_exception_ci : public be_visitor_exception
 {
 public:
   be_visitor_exception_ci (be_visitor_context *ctx);
-  ~be_visitor_exception_ci (void);
+  ~be_visitor_exception_ci ();
 
   virtual int visit_exception (be_exception *node);
 };
