@@ -23,7 +23,7 @@ class be_visitor_exception_ctor : public be_visitor_scope
 {
 public:
   be_visitor_exception_ctor (be_visitor_context *ctx);
-  ~be_visitor_exception_ctor (void);
+  ~be_visitor_exception_ctor ();
 
   virtual int post_process (be_decl *);
 
