@@ -15,7 +15,7 @@ class be_visitor_amh_interface_sh : public be_visitor_interface_sh
 {
 public:
   be_visitor_amh_interface_sh (be_visitor_context *ctx);
-  ~be_visitor_amh_interface_sh (void);
+  ~be_visitor_amh_interface_sh ();
 
   int visit_interface (be_interface *node);
   int visit_operation (be_operation *node);
