@@ -24,7 +24,7 @@ class be_visitor_interface_ci : public be_visitor_interface
 {
 public:
   be_visitor_interface_ci (be_visitor_context *ctx);
-  ~be_visitor_interface_ci (void);
+  ~be_visitor_interface_ci ();
 
   virtual int visit_interface (be_interface *node);
   virtual int visit_component (be_component *node);
