@@ -28,7 +28,7 @@ class be_visitor_interface_ex_idl : public be_visitor_interface
 public:
   be_visitor_interface_ex_idl (be_visitor_context *ctx);
 
-  ~be_visitor_interface_ex_idl (void);
+  ~be_visitor_interface_ex_idl ();
 
   virtual int visit_interface (be_interface *node);
 };
