@@ -28,7 +28,7 @@ class be_visitor_interface_svth : public be_visitor_interface
 public:
   be_visitor_interface_svth (be_visitor_context *ctx);
 
-  ~be_visitor_interface_svth (void);
+  ~be_visitor_interface_svth ();
 
   virtual int visit_interface (be_interface *node);
   virtual int visit_operation (be_operation *node);
