@@ -30,7 +30,7 @@ public:
   be_visitor_module_ih (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_module_ih (void);
+  ~be_visitor_module_ih ();
 
   /// visit module. We provide code for this method in the derived class
   virtual int visit_module (be_module *node);
