@@ -25,7 +25,7 @@ class be_visitor_amh_rh_operation_ss : public be_visitor_operation
  public:
     be_visitor_amh_rh_operation_ss (be_visitor_context *ctx);
 
-    ~be_visitor_amh_rh_operation_ss (void);
+    ~be_visitor_amh_rh_operation_ss ();
 
     int visit_operation (be_operation *node);
 
