@@ -22,7 +22,7 @@ class be_visitor_amh_operation_ss : public be_visitor_operation
 public:
   be_visitor_amh_operation_ss (be_visitor_context *ctx);
 
-  ~be_visitor_amh_operation_ss (void);
+  ~be_visitor_amh_operation_ss ();
 
   virtual int visit_operation (be_operation *node);
   virtual int visit_attribute (be_attribute *node);
