@@ -31,7 +31,7 @@ class be_visitor_operation_svs : public be_visitor_scope
 public:
   be_visitor_operation_svs (be_visitor_context *ctx);
 
-  ~be_visitor_operation_svs (void);
+  ~be_visitor_operation_svs ();
 
   virtual int visit_operation (be_operation *node);
   virtual int visit_argument (be_argument *node);
