@@ -30,7 +30,7 @@ public:
   be_visitor_operation_smart_proxy_cs (be_visitor_context *ctx);
 
   /// destructor
-  ~be_visitor_operation_smart_proxy_cs (void);
+  ~be_visitor_operation_smart_proxy_cs ();
 
   /// visit operation.
   virtual int visit_operation (be_operation *node);
