@@ -27,13 +27,13 @@ class be_visitor_root_ss : public be_visitor_root
 public:
   be_visitor_root_ss (be_visitor_context *ctx);
 
-  ~be_visitor_root_ss (void);
+  ~be_visitor_root_ss ();
 
   virtual int visit_root (be_root *node);
 
 private:
   /// Open file and initialize stream.
-  int init (void);
+  int init ();
 };
 
 #endif /* _BE_VISITOR_ROOT_ROOT_SS_H_ */
